@@ -60,11 +60,11 @@ _logger = logging.getLogger('FavoritesView')
 _ICON_DND_TARGET = ('activity-icon', Gtk.TargetFlags.SAME_WIDGET, 0)
 
 LAYOUT_MAP = {favoriteslayout.RingLayout.key: favoriteslayout.RingLayout,
-              # favoriteslayout.BoxLayout.key: favoriteslayout.BoxLayout,
-              # favoriteslayout.TriangleLayout.key:
-              # favoriteslayout.TriangleLayout,
-              # favoriteslayout.SunflowerLayout.key:
-              # favoriteslayout.SunflowerLayout,
+              favoriteslayout.BoxLayout.key: favoriteslayout.BoxLayout,
+              favoriteslayout.TriangleLayout.key:
+              favoriteslayout.TriangleLayout,
+              favoriteslayout.SunflowerLayout.key:
+              favoriteslayout.SunflowerLayout,
               favoriteslayout.RandomLayout.key: favoriteslayout.RandomLayout}
 """Map numeric layout identifiers to uninstantiated subclasses of
 `FavoritesLayout` which implement the layouts.  Additional information
@@ -176,9 +176,6 @@ class FavoritesView(ViewContainer):
             layout = favoriteslayout.RingLayout.key
             assert layout in LAYOUT_MAP
 
-        if isinstance(self._layout, LAYOUT_MAP[layout]):
-            return False
-
         if self._layout is not None and self._dragging_mode:
             self.disconnect(self._drag_motion_hid)
             self.disconnect(self._drag_drop_hid)
